@@ -26,26 +26,22 @@ class Parser:
     def parse_data(self):
         tables = []
         table = []
-        # todo: need to re-done this and parse table defenitions same way till ;
-        is_table = False
         statement = None
         for line in self.data.split("\n"):
             if line.replace("\n", "").replace("\t", ""):
+                # to avoid issues when comma are glued to column name
+                line = line.replace(",", " , ").replace("(", " ( ").replace(")", " ) ")
                 if "CREATE" in line.upper() and "TABLE" in line.upper():
-                    is_table = True
                     statement = line
-                elif statement != None and not is_table:
+                elif statement != None:
                     statement += f" {line}"
                 elif "TABLE" not in line.upper() and not statement:
                     statement = line
                 else:
                     statement = line
-                if ";" not in statement and not is_table:
+                if ";" not in statement:
                     continue
-                if ";" in line and is_table:
-                    is_table = False
                 _parse_result = yacc.parse(statement)
-                self.sequence = False
                 if _parse_result:
                     table.append(_parse_result)
                 if line.strip().endswith(";"):
@@ -58,7 +54,7 @@ class Parser:
     def run(
         self, *, dump=None, dump_path="schemas", file_path: Optional[str] = None
     ) -> List[Dict]:
-        """ run lex and yacc on prepared data from files """
+        """ run parser """
         tables = self.parse_data()
         tables = result_format(tables)
         if dump:
